"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.recipesRouter = void 0;
const express_1 = require("express");
const uuid_1 = require("uuid");
const Recipe_1 = require("../models/Recipe");
const passport = require("passport");
const validate_1 = require("../utils/validation/validate");
const recipeValidationSchema_1 = require("../utils/validation/recipeValidationSchema");
exports.recipesRouter = (0, express_1.Router)();
exports.recipesRouter
    .get('', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const recipes = yield Recipe_1.Recipe.findAll().catch(err => {
        res
            .status(500)
            .json({ message: 'Wystąpił błąd, spróbuj ponownie pózniej.' });
    });
    // @ts-ignore
    if (recipes.length === 0) {
        res
            .status(400)
            .json({ message: "Aktualnie nie ma żadnych przepisów. " });
        return;
    }
    if (recipes) {
        res
            .status(200)
            .json(recipes);
    }
}))
    .get('/:name', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { name } = req.params;
    const oneRecipe = yield Recipe_1.Recipe.findOne({ where: { name } }).catch(err => {
        res
            .status(500)
            .json({ message: 'Wystąpił błąd, spróbuj ponownie później.' });
    });
    if (oneRecipe) {
        res
            .status(200)
            .json(oneRecipe);
    }
    else {
        res
            .status(400)
            .json({ message: 'Przepis o takiej nazwie nie istnieje.' });
    }
}))
    .get('/search/:category', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { category } = req.params;
    const recipesWithCategory = yield Recipe_1.Recipe.findAll({ where: { category } }).catch(err => {
        res
            .status(500)
            .json({ message: 'Wystąpił błąd, spróbuj ponownie później.' });
    });
    // @ts-ignore
    if (recipesWithCategory.length === 0) {
        res
            .status(400)
            .json({ message: 'Nie istnieją żadne przepisy w podanej kategorii.' });
        return;
    }
    if (recipesWithCategory) {
        res
            .status(200)
            .json(recipesWithCategory);
    }
}))
    // @ts-ignore
    .post('/add-recipe', [passport.authenticate("jwt", { session: false }), (0, validate_1.validate)(recipeValidationSchema_1.validationRecipeSchema)], (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { authorId, name, description, category, ingredients, todoList, imagePath } = req.body;
    const recipeNameExist = yield Recipe_1.Recipe.findOne({ where: { name } }).catch(err => {
        console.log(err);
    });
    if (recipeNameExist) {
        return res
            .status(400)
            .json({ message: "Przepis o podanej nazwie już istnieje." });
    }
    const id = (0, uuid_1.v4)();
    // @ts-ignore
    const newRecipe = new Recipe_1.Recipe({
        id,
        authorId,
        name,
        description,
        category,
        ingredients,
        todoList,
        imagePath
    });
    const saveRecipe = yield newRecipe.save()
        .catch(err => {
        console.log(err);
        res.status(500)
            .json({ message: "Dodawanie nowego przepisu nie udało się, spróbuj ponownie" });
    });
    if (saveRecipe) {
        res.json({ message: `Pomyślnie dodano ${name} do przepisów.` });
    }
}))
    .patch('/:id', [passport.authenticate("jwt", { session: false }), (0, validate_1.validate)(recipeValidationSchema_1.validationRecipeSchema)], (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { id } = req.params;
    const { name, description, category, ingredients, todoList, imagePath } = req.body;
    const recipe = yield Recipe_1.Recipe.findOne({ where: { id } }).catch(err => {
        console.log(err);
        res.status(500)
            .json({ message: "Edycja przepisu nie udała się, spróbuj ponownie" });
    });
    if (!recipe) {
        return res
            .status(400)
            .json({ message: "Przepis o podanym id nie istnieje." });
    }
    recipe.name = name;
    recipe.description = description;
    recipe.category = category;
    recipe.ingredients = ingredients;
    recipe.todoList = todoList;
    recipe.imagePath = imagePath;
    yield recipe.save();
    return res
        .status(200)
        .json({ message: "Pomyślnie zaktualizowano przepis." });
}))
    .delete('/:id', passport.authenticate("jwt", { session: false }), (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { id } = req.params;
    const recipe = yield Recipe_1.Recipe.findOne({ where: { id } }).catch(err => {
        console.log(err);
        res.status(500)
            .json({ message: "Usuwanie przepisu nie udało się, spróbuj ponownie" });
    });
    if (recipe) {
        yield recipe.destroy();
        return res
            .status(200)
            .json({ message: "Pomyślnie usunięto przepis." });
    }
    return res
        .status(400)
        .json({ message: "Przepis o podanym id nie istnieje." });
}));
//# sourceMappingURL=recipes.js.map