"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.usersRouter = void 0;
const express_1 = require("express");
const uuid_1 = require("uuid");
const bcrypt = require("bcrypt");
const jwt = require("jsonwebtoken");
const User_1 = require("../models/User");
const passport = require("passport");
const validate_1 = require("../utils/validation/validate");
const userValidationSchema_1 = require("../utils/validation/userValidationSchema");
exports.usersRouter = (0, express_1.Router)();
exports.usersRouter
    .get('', (req, res) => {
    res.json({ message: "test" });
})
    // @ts-ignore
    .post('/register', (0, validate_1.validate)(userValidationSchema_1.validationUserSchema), (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { username, email, password } = req.body;
    const userEmailExists = yield User_1.User.findOne({ where: { email } }).catch((err) => {
        console.log(err);
    });
    if (userEmailExists) {
        return res
            .status(400)
            .json({ message: "Użytkownik z podanym emailem już istnieje" });
    }
    ;
    const userUsernameExists = yield User_1.User.findOne({ where: { username } }).catch((err) => {
        console.log(err);
    });
    if (userUsernameExists) {
        return res
            .status(400)
            .json({ message: "Użytkownik z podaną nazwą użytkownika już istnieje" });
    }
    ;
    if (username.length > 30 || email.length > 30) {
        return res
            .status(400)
            .json({ message: "Nazwa użytkownika oraz email nie mogą mieć więcej niż 30 znaków" });
    }
    const id = (0, uuid_1.v4)();
    const salt = yield bcrypt.genSalt(10);
    const user_password = yield bcrypt.hash(password, salt);
    console.log(user_password);
    // @ts-ignore
    const newUser = new User_1.User({
        id,
        username,
        email,
        password: user_password
    });
    const saveUser = yield newUser.save()
        .catch((error) => {
        console.log(error);
        res
            .status(500)
            .json({ message: 'Rejestracja się nie powiodła, spróbuj ponownie póżniej.' });
    });
    if (saveUser)
        res.json({ message: 'Rejestracja się powiodła', id: id });
}))
    .post('/login', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { email, password } = req.body;
    const userEmail = yield User_1.User.findOne({ where: { email } })
        .catch((err) => {
        console.error("error", err);
    });
    if (userEmail) {
        const validPassword = yield bcrypt.compare(password, userEmail.password);
        if (validPassword) {
            const jwtToken = jwt.sign({ id: userEmail.id, email: userEmail.email, username: userEmail.username }, process.env.JWT_SECRET);
            res
                .status(200)
                .json({ message: "Pomyślnie zalogowano", token: jwtToken });
        }
        else {
            res
                .status(400)
                .json({ message: "Podano niepoprawny email lub hasło" }); // hasło
        }
    }
    else {
        res.status(401)
            .json({ message: "Użytkownik z podanym emailem nie istnieje" });
    }
}))
    .patch('/update', [passport.authenticate("jwt", { session: false }), (0, validate_1.validate)(userValidationSchema_1.validationUserSchema)], (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { id, username, email } = req.body;
    const user = yield User_1.User.findOne({ where: { id } })
        .catch((err) => {
        console.error("error", err);
    });
    if (user) {
        user.username = username;
        user.email = email;
        yield user.save();
        res
            .status(200)
            .json({ message: `Pomyślnie zaktualizowano dane: email ${email} oraz nazwa użytkownika ${username}` });
    }
    else {
        res
            .status(400)
            .json({ message: "Nie znaleziono uzytkownika" });
    }
}));
//# sourceMappingURL=users.js.map