import {Request, Response, Router} from "express";
import { v4 as uuid} from "uuid";
import * as bcrypt from "bcrypt";
import * as jwt from "jsonwebtoken";
import {User} from "../models/User";
import * as passport from "passport";
import { body, validationResult } from 'express-validator';
import {validate} from "../utils/validation/validate";
import {validationUserSchema} from "../utils/validation/userValidationSchema";

export const usersRouter = Router();


usersRouter
    .get('', (req,res) => {
        res.json({message: "test"})
    })
    // @ts-ignore
    .post('/register', validate(validationUserSchema), async (req, res) => {
        const {username, email, password} = req.body;

        const userEmailExists = await User.findOne({where: { email }}).catch(
            (err) => {
                console.log(err);
            }
        );

        if(userEmailExists) {
            return res
                .status(400)
                .json({ message: "Użytkownik z podanym emailem już istnieje"});
        };

        const userUsernameExists = await User.findOne({where: { username }}).catch(
            (err) => {
                console.log(err);
            }
        );

        if(userUsernameExists) {
            return res
                .status(400)
                .json({ message: "Użytkownik z podaną nazwą użytkownika już istnieje"});
        };

        if(username.length > 30 || email.length > 30) {
            return res
                .status(400)
                .json({message: "Nazwa użytkownika oraz email nie mogą mieć więcej niż 30 znaków"})
        }

        const id = uuid();

        const salt = await bcrypt.genSalt(10);
        const user_password = await bcrypt.hash(password, salt)
        console.log(user_password)

        // @ts-ignore
        const newUser = new User({
            id,
            username,
            email,
            password: user_password
        });

        const saveUser = await newUser.save()
            .catch((error) => {
                console.log(error);
                res
                    .status(500)
                    .json({ message: 'Rejestracja się nie powiodła, spróbuj ponownie póżniej.'})
        });

        if(saveUser)
            res.json( { message: 'Rejestracja się powiodła', id: id});
    })
    .post('/login', async (req, res) => {
        const { email, password } = req.body;

        const userEmail = await User.findOne({ where: { email }})
            .catch((err) => {
               console.error("error", err) ;
            });

        if(userEmail) {
            const validPassword = await bcrypt.compare(password, userEmail.password);
            if (validPassword) {
                const jwtToken = jwt.sign(
                    {id: userEmail.id, email: userEmail.email, username: userEmail.username},
                    process.env.JWT_SECRET
                )

                res
                    .status(200)
                    .json({ message: "Pomyślnie zalogowano", token: jwtToken })
            } else {
                res
                    .status(400)
                    .json({ message: "Podano niepoprawny email lub hasło"}); // hasło
            }
        } else {
            res.status(401)
                .json({message: "Użytkownik z podanym emailem nie istnieje"})
        }
    })
    .patch('/update', [passport.authenticate("jwt", { session: false}), validate(validationUserSchema)], async (req: Request, res: Response) => {
        const { id, username, email } = req.body;



        const user = await User.findOne({ where: { id }})
            .catch((err) => {
                console.error("error", err) ;
            });

        if(user) {
            user.username = username;
            user.email = email;
            await user.save();
            res
                .status(200)
                .json({ message: `Pomyślnie zaktualizowano dane: email ${email} oraz nazwa użytkownika ${username}`})
        } else {
            res
                .status(400)
                .json({ message: "Nie znaleziono uzytkownika" })
        }
    });
